@@ -18,6 +18,7 @@ ATTENDEE;CN=Strunk;PARTSTAT=ACCEPTED:mailto:strunk@example.org
 ATTENDEE;CN=One:mailto:one@example.org
 ATTENDEE;CN=Two:mailto:two@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS;
@@ -35,6 +36,7 @@ ATTENDEE;CN=Strunk;PARTSTAT=ACCEPTED:mailto:strunk@example.org
 ATTENDEE;CN=Two:mailto:two@example.org
 ATTENDEE;CN=Three:mailto:three@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS;
@@ -62,6 +64,7 @@ UID:foobar
 SEQUENCE:2
 SUMMARY:foo
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=One:mailto:one@example.org
 END:VEVENT
@@ -93,6 +96,7 @@ ATTENDEE;CN=Strunk;PARTSTAT=ACCEPTED:mailto:strunk@example.org
 ATTENDEE;CN=Two;PARTSTAT=NEEDS-ACTION:mailto:two@example.org
 ATTENDEE;CN=Three;PARTSTAT=NEEDS-ACTION:mailto:three@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS
@@ -122,6 +126,7 @@ ATTENDEE;CN=Strunk;PARTSTAT=ACCEPTED:mailto:strunk@example.org
 ATTENDEE;CN=Two;PARTSTAT=NEEDS-ACTION:mailto:two@example.org
 ATTENDEE;CN=Three;PARTSTAT=NEEDS-ACTION:mailto:three@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS
@@ -142,6 +147,7 @@ BEGIN:VEVENT
 UID:foobar
 SEQUENCE:1
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS;
@@ -156,6 +162,7 @@ SEQUENCE:2
 ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=One:mailto:one@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS;
@@ -183,6 +190,7 @@ SEQUENCE:2
 ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=One;PARTSTAT=NEEDS-ACTION:mailto:one@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS
@@ -206,6 +214,7 @@ SEQUENCE:2
 ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=One:mailto:one@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS;
@@ -218,6 +227,7 @@ BEGIN:VEVENT
 UID:foobar
 SEQUENCE:1
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS;
@@ -239,6 +249,7 @@ BEGIN:VEVENT
 UID:foobar
 SEQUENCE:1
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=One:mailto:one@example.org
 END:VEVENT
@@ -262,6 +273,7 @@ BEGIN:VEVENT
 UID:foobar
 SEQUENCE:1
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS;
@@ -274,6 +286,7 @@ BEGIN:VEVENT
 UID:foobar
 SEQUENCE:2
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS;
@@ -296,6 +309,7 @@ SEQUENCE:1
 ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=One:mailto:one@example.org
 DTSTART;TZID=America/Toronto:20140716T120000
+DTEND;TZID=America/Toronto:20140716T130000
 RRULE:FREQ=WEEKLY
 END:VEVENT
 END:VCALENDAR
@@ -311,6 +325,7 @@ SEQUENCE:2
 ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=One:mailto:one@example.org
 DTSTART;TZID=America/Toronto:20140716T120000
+DTEND;TZID=America/Toronto:20140716T130000
 RRULE:FREQ=WEEKLY
 EXDATE;TZID=America/Toronto:20140724T120000
 END:VEVENT
@@ -340,6 +355,7 @@ SEQUENCE:2
 ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=One;PARTSTAT=NEEDS-ACTION:mailto:one@example.org
 DTSTART;TZID=America/Toronto:20140716T120000
+DTEND;TZID=America/Toronto:20140716T130000
 RRULE:FREQ=WEEKLY
 EXDATE;TZID=America/Toronto:20140724T120000
 END:VEVENT
@@ -373,6 +389,7 @@ ATTENDEE;CN=Strunk;PARTSTAT=ACCEPTED:mailto:strunk@example.org
 ATTENDEE;CN=One:mailto:one@example.org
 ATTENDEE;CN=Two:mailto:two@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS;
@@ -390,6 +407,7 @@ ATTENDEE;CN=Strunk;PARTSTAT=ACCEPTED:mailto:strunk@example.org
 ATTENDEE;CN=Two:mailto:two@example.org
 ATTENDEE;CN=Three:mailto:three@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS;
@@ -416,6 +434,7 @@ BEGIN:VEVENT
 UID:foobar
 SEQUENCE:2
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=One:mailto:one@example.org
 END:VEVENT
@@ -447,6 +466,7 @@ ATTENDEE;CN=Strunk;PARTSTAT=ACCEPTED:mailto:strunk@example.org
 ATTENDEE;CN=Two;PARTSTAT=NEEDS-ACTION:mailto:two@example.org
 ATTENDEE;CN=Three;PARTSTAT=NEEDS-ACTION:mailto:three@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS
@@ -476,6 +496,7 @@ ATTENDEE;CN=Strunk;PARTSTAT=ACCEPTED:mailto:strunk@example.org
 ATTENDEE;CN=Two;PARTSTAT=NEEDS-ACTION:mailto:two@example.org
 ATTENDEE;CN=Three;PARTSTAT=NEEDS-ACTION:mailto:three@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS
@@ -499,6 +520,7 @@ ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=Strunk;PARTSTAT=ACCEPTED:mailto:strunk@example.org
 ATTENDEE;CN=One:mailto:one@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS;
@@ -514,6 +536,7 @@ ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=Strunk;PARTSTAT=ACCEPTED:mailto:strunk@example.org
 ATTENDEE;CN=One:mailto:one@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS;
@@ -543,6 +566,7 @@ ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=Strunk;PARTSTAT=ACCEPTED:mailto:strunk@example.org
 ATTENDEE;CN=One;PARTSTAT=NEEDS-ACTION:mailto:one@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS
@@ -567,6 +591,7 @@ ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=Strunk;PARTSTAT=ACCEPTED:mailto:strunk@example.org
 ATTENDEE;CN=One:mailto:one@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS;
@@ -582,6 +607,7 @@ ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=Strunk;PARTSTAT=ACCEPTED:mailto:strunk@example.org
 ATTENDEE;SCHEDULE-FORCE-SEND=REQUEST;CN=One:mailto:one@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS;
@@ -611,6 +637,7 @@ ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=Strunk;PARTSTAT=ACCEPTED:mailto:strunk@example.org
 ATTENDEE;CN=One;PARTSTAT=NEEDS-ACTION:mailto:one@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS
@@ -637,6 +664,7 @@ ATTENDEE;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=One:mailto:one@example.org
 ATTENDEE;CN=Two:mailto:two@example.org
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS;
@@ -650,6 +678,7 @@ UID:foobar
 SEQUENCE:2
 SUMMARY:foo
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 END:VEVENT
 END:VCALENDAR
 ICS;
@@ -677,6 +706,7 @@ UID:foobar
 SEQUENCE:2
 SUMMARY:foo
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=One:mailto:one@example.org
 END:VEVENT
@@ -704,6 +734,7 @@ UID:foobar
 SEQUENCE:2
 SUMMARY:foo
 DTSTART:20140716T120000Z
+DTEND:20140716T130000Z
 ORGANIZER;CN=Strunk:mailto:strunk@example.org
 ATTENDEE;CN=Two:mailto:two@example.org
 END:VEVENT
